==> openshift-model-monitoring-5.7.3-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/PrometheusRuleListBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PrometheusRuleListBuilder extends io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleListFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleList,io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleListBuilder>{
  public PrometheusRuleListBuilder() {
    this(false);
  }
  public PrometheusRuleListBuilder(java.lang.Boolean validationEnabled) {
    this(new PrometheusRuleList(), validationEnabled);
  }
  public PrometheusRuleListBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleListFluent<?> fluent) {
    this(fluent, false);
  }
  public PrometheusRuleListBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PrometheusRuleList(), validationEnabled);
  }
  public PrometheusRuleListBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleListFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleList instance) {
    this(fluent, instance, false);
  }
  public PrometheusRuleListBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleListFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  public PrometheusRuleListBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleList instance) {
    this(instance,false);
  }
  public PrometheusRuleListBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleList build() {
    PrometheusRuleList buildable = new PrometheusRuleList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PrometheusRuleListBuilder that = (PrometheusRuleListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/PrometheusRuleListBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PrometheusRuleListBuilder extends io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleListFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleList,io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleListBuilder>{
  public PrometheusRuleListBuilder() {
    this(false);
  }
  public PrometheusRuleListBuilder(java.lang.Boolean validationEnabled) {
    this(new PrometheusRuleList(), validationEnabled);
  }
  public PrometheusRuleListBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleListFluent<?> fluent) {
    this(fluent, false);
  }
  public PrometheusRuleListBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PrometheusRuleList(), validationEnabled);
  }
  public PrometheusRuleListBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleListFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleList instance) {
    this(fluent, instance, false);
  }
  public PrometheusRuleListBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleListFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PrometheusRuleListBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleList instance) {
    this(instance,false);
  }
  public PrometheusRuleListBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleList build() {
    PrometheusRuleList buildable = new PrometheusRuleList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PrometheusRuleListBuilder that = (PrometheusRuleListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
